@@ -1,10 +1,14 @@
 from typing import Optional
 
+from httpx import Timeout
+
 from firebolt.client import Client, log_request, log_response, raise_on_4xx_5xx
 from firebolt.common import Settings
 from firebolt.common.urls import ACCOUNT_BY_NAME_URL
 from firebolt.service.provider import get_provider_id
 
+DEFAULT_TIMEOUT_SECONDS: int = 60 * 2
+
 
 class ResourceManager:
     """
@@ -29,6 +33,7 @@ class ResourceManager:
             auth=(self.settings.user, self.settings.password.get_secret_value()),
             base_url=f"https://{ self.settings.server}",
             api_endpoint=self.settings.server,
+            timeout=Timeout(DEFAULT_TIMEOUT_SECONDS),
         )
         self.client.event_hooks = {
             "request": [log_request],
